@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2004-2007  QRW Software
+--                 Copyright (C) 2004-2008  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,66 @@
 --
 --
 -- $Log: disk_io.c,v $
+-- Revision 1.69  2008/02/04 03:10:19  jsedwards
+-- Changed to get backup directory path from user_config.
+--
+-- Revision 1.68  2008/02/03 02:11:22  jsedwards
+-- Change to use the new nwos_get_private_objects_path function that checks
+-- for environment variable and configuration file.
+--
+-- Revision 1.67  2008/02/03 02:05:42  jsedwards
+-- Fixed wrong path for public objects broken in previous check in.
+--
+-- Revision 1.66  2008/02/03 01:46:34  jsedwards
+-- Reverted some of the changes made in revision 1.64 for the nwos_public_path
+-- back to the way they were in 1.63.
+--
+-- Revision 1.65  2008/02/03 01:39:50  jsedwards
+-- Fix to compile without warnings in PUBLIC_MODE.
+--
+-- Revision 1.64  2008/01/22 14:55:25  jsedwards
+-- Changed to call nwos_get_public_objects_path() in new user_config.c file,
+-- instead of having a global variable.
+--
+-- Revision 1.63  2008/01/17 15:04:02  jsedwards
+-- Moved progress bar code to prep_disk.c and instead pass a function pointer
+-- in that is called (if non-null) with progress.
+--
+-- Revision 1.62  2008/01/17 14:42:59  jsedwards
+-- Fixed the progress bar so it works correctly even for small sizes.
+--
+-- Revision 1.61  2008/01/17 14:33:36  jsedwards
+-- Took code added in previous revision back out because in the sparse file
+-- case the entire file has already been written, all we have to do is
+-- allocate the chunks.  This revision should be the same as Revision 1.59.
+--
+-- Revision 1.60  2008/01/17 13:44:45  jsedwards
+-- Added code to allocate all hack that checks to see if it is a sparse file
+-- or a partition and writes the whole chunk if it is a sparse file.  This is
+-- necessary for the time being because if we only write the bit map to a
+-- sparse file it really will create a sparse file which wastes a lot of disk
+-- space.
+--
+-- Revision 1.59  2008/01/17 05:13:55  jsedwards
+-- Added call to flush data after each bit map block write and usleep 10 mS.
+--
+-- Revision 1.58  2008/01/17 05:05:44  jsedwards
+-- Changed to just write the bit map bytes into each chunk allocated instead
+-- of writing the entire chunk with zeros.  Should no longer be necessary to
+-- write all the zeros because the it map determines if the block is used or
+-- not.
+--
+-- Revision 1.57  2008/01/17 04:55:59  jsedwards
+-- Added code to print the progress in the allocate_all_hack function.
+--
+-- Revision 1.56  2007/12/09 16:56:14  jsedwards
+-- Changed assert to more descriptive prints, when block isn't found in
+-- storage_index.
+--
+-- Revision 1.55  2007/12/09 16:49:29  jsedwards
+-- Comment out statement in terminate_disk_io that nulled out the public_path,
+-- so we can start objectify back up again if necessary.
+--
 -- Revision 1.54  2007/11/13 15:01:33  jsedwards
 -- Added #ifndef NO_BACKUP around calls to backup module.  This way we don't
 -- have to include it when compiling export_c_structs.
@@ -249,8 +309,8 @@
 
 static Disk_Header disk_header;
 
-char*  nwos_public_path = DEFAULT_PUBLIC_PATH;
-char*  nwos_private_path;
+const char*  nwos_public_path;
+const char*  nwos_private_path;
 
 uint32 nwos_total_private_blocks;
 uint32 nwos_used_public_blocks;
@@ -275,8 +335,10 @@ static uint16* chunk_used_index;  /* order of chunks sorted by blocks used, fewe
 
 static uint32 block_estimate;
 static uint32 last_used_blocks;
-static ObjRef last_ref;
 
+#ifndef PUBLIC_MODE
+static ObjRef last_ref;
+#endif
 
 
 #define BIT_MAP_CACHE_SIZE 256
@@ -295,9 +357,11 @@ static int bit_map_tick = 0;
 
 static void write_bit_map(Bit_Map_Cache_Entry* entry);
 
+#ifndef PUBLIC_MODE
 static uint32 chunk_density_target;
 static int32  chunk_skip_backward;
 static int32  chunk_skip_forward;
+#endif
 
 
 /*************************/
@@ -505,7 +569,7 @@ void initialize_random_number_generator()
 }
 
 
-void nwos_initialize_disk_io(StorageType type, char* path)
+void nwos_initialize_disk_io(AccessType type, const char* path)
 {
     size_t chunk_info_size_in_bytes;
     char log_msg[128];
@@ -516,11 +580,17 @@ void nwos_initialize_disk_io(StorageType type, char* path)
     uint16 left;
     uint16 right;
     uint16 save;
-
+    bool compressed_file;
+#ifndef NO_BACKUP
+    const char* backup_dir;
+#endif
 
     /* make sure the storage is something we can deal with */
-    assert(type == Drive_Or_Partition_RO || type == Drive_Or_Partition_RW || 
-	   type == Sparse_File_RO || type == Sparse_File_RW || type == Compressed_File_RO);
+#ifdef PUBLIC_MODE
+    assert(type == 0);
+#else
+    assert(type == READ_ONLY || type == READ_WRITE);
+#endif
 
     assert(nwos_private_path == NULL);   /* make sure this is only called once */
     assert(private_file_desc == 0);
@@ -528,7 +598,23 @@ void nwos_initialize_disk_io(StorageType type, char* path)
 
     initialize_random_number_generator();
 
-    nwos_private_path = path;
+    nwos_public_path = nwos_get_public_objects_path();
+
+#ifdef PUBLIC_MODE
+    assert(path == NULL);
+#else
+    if (path == NULL)    /* no compressed file was passed in */
+    {
+	nwos_private_path = nwos_get_private_objects_path();
+	compressed_file = (strstr(nwos_private_path, "compressed") != NULL);
+    }
+    else
+    {
+	assert(type == READ_ONLY);
+	nwos_private_path = path;
+	compressed_file = true;
+    }
+#endif
 
     /********************************/
     /* open the public objects file */
@@ -581,7 +667,7 @@ void nwos_initialize_disk_io(StorageType type, char* path)
 
     if (nwos_private_path != NULL)
     {
-	read_only = ((type & 1) == 0);
+	read_only = (type == READ_ONLY);
 
 	if (read_only)
 	{
@@ -598,7 +684,7 @@ void nwos_initialize_disk_io(StorageType type, char* path)
 	    exit(1);
 	}
 
-	if (type == Compressed_File_RO)
+	if (compressed_file)
 	{
 	    index_compressed_file();   /* build an index into the compressed file */
 
@@ -626,9 +712,8 @@ void nwos_initialize_disk_io(StorageType type, char* path)
 	{
 	    // allow more compressed files to be other compatible versions
 
-	    if (type != Compressed_File_RO ||
-		memcmp(disk_header.version_string, VERSION_STRING, 4) > 0 ||
-	        memcmp(disk_header.version_string, OLDEST_COMPATIBLE_COMPRESSED_VERSION, 4) < 0)
+	    if ((compressed_file && memcmp(disk_header.version_string, OLDEST_COMPATIBLE_COMPRESSED_VERSION, 4) < 0) ||
+		(!compressed_file && memcmp(disk_header.version_string, VERSION_STRING, 4) != 0))
 	    {
 		fprintf(stderr, "Incorrect version string in disk header\n");
 		exit(1);
@@ -734,7 +819,7 @@ void nwos_initialize_disk_io(StorageType type, char* path)
 	    chunk_used_index[j - 1] = save;
 	}
 
-	if (type == Drive_Or_Partition_RO || type == Drive_Or_Partition_RW)
+	if (!compressed_file)
 	{
 	    assert(nwos_total_private_blocks > 0);
 	}
@@ -745,9 +830,11 @@ void nwos_initialize_disk_io(StorageType type, char* path)
 #ifndef NO_BACKUP
 	/* Do a backup file? */
 
-	if (BACKUP_LOCATION != NULL && !read_only)
+	backup_dir = nwos_get_backup_directory_path();
+
+	if (backup_dir != NULL && !read_only)
 	{
-	    nwos_initialize_backup(BACKUP_LOCATION, &disk_header);
+	    nwos_initialize_backup(backup_dir, &disk_header);
 	}
 #endif
     }
@@ -875,7 +962,6 @@ void nwos_terminate_disk_io()
     }
 
     public_file_desc = 0;
-    nwos_public_path = NULL;
 
     log_estimate_results();
 }
@@ -960,7 +1046,7 @@ void nwos_allocate_new_chunk(uint32 ref)
 }
 
 
-void nwos_allocate_all_chunks_hack(uint32 ref)
+void nwos_allocate_all_chunks_hack(uint32 ref, void (*progress_report)(float))
 {
     uint32 offset;
     static uint8* chunk;
@@ -991,6 +1077,11 @@ void nwos_allocate_all_chunks_hack(uint32 ref)
 
     while (nwos_used_private_chunks < nwos_total_private_chunks)
     {
+	if (progress_report != NULL)
+	{
+	    (*progress_report)((float)nwos_used_private_chunks / (float)nwos_total_private_chunks);
+	}
+
 	chunk_info[nwos_used_private_chunks].ref = normalized_ref;
 	chunk_info[nwos_used_private_chunks].index = nwos_used_private_chunks;
 
@@ -1002,12 +1093,20 @@ void nwos_allocate_all_chunks_hack(uint32 ref)
 	    exit(1);
 	}
 
-	if (write(private_file_desc, chunk, CHUNK_SIZE) != CHUNK_SIZE)
+	if (write(private_file_desc, chunk, BIT_MAP_BYTES) != BIT_MAP_BYTES)
 	{
 	    perror(nwos_private_path);
 	    exit(1);
 	}
 
+	if (fdatasync(private_file_desc) != 0)
+	{
+	    perror(nwos_private_path);
+	    exit(1);
+	}
+
+	usleep(10000);
+
 	normalized_ref += USABLE_BLOCKS_PER_CHUNK;
 
 	nwos_used_private_chunks += 1;
@@ -1038,6 +1137,7 @@ float nwos_private_space_used()
 /* -1 if not found.                                                                           */
 /**********************************************************************************************/
 
+#ifndef PUBLIC_MODE
 static int uint32_ref_to_info_index(uint32 ref)
 {
     int lwr;
@@ -1080,6 +1180,7 @@ static int uint32_ref_to_info_index(uint32 ref)
 
     return -1;   /* not found */
 }
+#endif
 
 
 /*********************************************************************************************/
@@ -2192,7 +2293,37 @@ bool nwos_read_block(ObjRef* ref, uint8 block[FILE_BLOCK_SIZE])
 	    }
 	}
 
-	assert(lower <= upper);
+	if (lower > upper)
+	{
+	    int i;
+
+	    fprintf(stderr, "Can't find %08x in index table:\n", ref_hash);
+	    fflush(stderr);
+
+	    if (ref_hash < nwos_ref_to_word(&storage_index[0]))
+	    {
+		i = 0;
+	    }
+	    else
+	    {
+		for (i = 1; i < storage_count; i++)
+		{
+		    if (nwos_ref_to_word(&storage_index[i-1]) < ref_hash && ref_hash < nwos_ref_to_word(&storage_index[i])) break;
+		}
+	    }
+
+	    if (i > 0)
+	    {
+		fprintf(stderr, "  %d: %08x\n", i-1, nwos_ref_to_word(&storage_index[i-1]));
+	    }
+
+	    if (i < storage_count)
+	    {
+		fprintf(stderr, "  %d: %08x\n", i, nwos_ref_to_word(&storage_index[i]));
+	    }
+
+	    exit(1);
+	}
 
 	assert(is_same_object(&storage_index[i], ref));
 
