@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                Copyright (C) 2006, 2007  QRW Software
+--                 Copyright (C) 2006-2008  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,9 @@
 --
 --
 -- $Log: expand_sparse.c,v $
+-- Revision 1.25  2008/02/03 01:15:40  jsedwards
+-- Change to use nwos_get_private_objects_path function instead of DEFAULT_FILE.
+--
 -- Revision 1.24  2007/11/20 06:07:38  jsedwards
 -- Fix to close backup file after initialize_objectify so no backup will be
 -- written while restoring.
@@ -163,6 +166,7 @@ static void print_usage(char *program)
 
 int main(int argc, char* argv[])
 {
+    const char* obj_file_path;
     uint8 block[FILE_BLOCK_SIZE];
     size_t bytes_read;
     FILE* ifp;
@@ -196,16 +200,18 @@ int main(int argc, char* argv[])
 
     nwos_log_arguments(argc, argv);
 
-    nwos_initialize_objectify(NULL, 0, 0, DEFAULT_TYPE_RW, DEFAULT_FILE);
+    obj_file_path = nwos_get_private_objects_path();
+
+    nwos_initialize_objectify(NULL, 0, 0, READ_WRITE, obj_file_path);
 
     nwos_terminate_backup(false, NULL);   /* don't create a backup file */
 
     /* Verify that is what s/he really wants to do */
 
     fprintf(stderr, "\n");
-    fprintf(stderr, "WARNING: the contents of %s will be OVERWRITTEN!!!\n", DEFAULT_FILE);
+    fprintf(stderr, "WARNING: the contents of %s will be OVERWRITTEN!!!\n", obj_file_path);
     fprintf(stderr, "\n");
-    fprintf(stderr, "Do you want to continue? (enter `yes' to write %s) ", DEFAULT_FILE);
+    fprintf(stderr, "Do you want to continue? (enter `yes' to write %s) ", obj_file_path);
 
     fflush(stderr);
 
