@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                Copyright (C) 2006, 2007  QRW Software
+--                 Copyright (C) 2006-2008  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,10 @@
 --
 --
 -- $Log: export_file.c,v $
+-- Revision 1.18  2008/02/03 01:04:28  jsedwards
+-- Changed DEFAULT_TYPE_RO to READ_ONLY and changed path variable to const char
+-- instead of char.
+--
 -- Revision 1.17  2007/09/18 01:22:29  jsedwards
 -- Rearrange the order of testing for an old (depreciated) file name, so that
 -- it is only done if the file name matches.  That way the association object
@@ -201,8 +205,7 @@ int main(int argc, char* argv[])
     int i;
     int j;
     int k;
-    StorageType type = DEFAULT_TYPE_RO;
-    char* path = DEFAULT_FILE;
+    const char* path = DEFAULT_FILE;
     char name[256];
     ReferenceList* ref_list;
     int num_refs;
@@ -218,7 +221,6 @@ int main(int argc, char* argv[])
 	    exit(1);
 	}
 
-	type = Compressed_File_RO;
 	path = argv[2];
 	argn = 3;
     }
@@ -238,7 +240,7 @@ int main(int argc, char* argv[])
     memcpy(root_object_ref.id, big_key+20, 4);
     serial = ((uint32)big_key[24] << 24) | ((uint32)big_key[25] << 16) | ((uint32)big_key[26] << 8) | (uint32)big_key[27];
 
-    nwos_initialize_objectify(bf_key, linear, serial, type, path);
+    nwos_initialize_objectify(bf_key, linear, serial, READ_ONLY, path);
 
     nwos_set_root_object(&root_object_ref);
 
