@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                Copyright (C) 2006, 2007  QRW Software
+--                 Copyright (C) 2006-2008  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,9 @@
 --
 --
 -- $Log: import_file.c,v $
+-- Revision 1.20  2008/02/03 01:00:35  jsedwards
+-- Changed DEFAULT_TYPE_RW to READ_WRITE.
+--
 -- Revision 1.19  2007/11/04 13:06:02  jsedwards
 -- Added an extra note to look at Security_Levels.txt file in display_usage.
 --
@@ -223,7 +226,7 @@ int main(int argc, char* argv[])
     memcpy(root_object_ref.id, big_key+20, 4);
     serial = ((uint32)big_key[24] << 24) | ((uint32)big_key[25] << 16) | ((uint32)big_key[26] << 8) | (uint32)big_key[27];
 
-    nwos_initialize_objectify(bf_key, linear, serial, DEFAULT_TYPE_RW, DEFAULT_FILE);
+    nwos_initialize_objectify(bf_key, linear, serial, READ_WRITE, DEFAULT_FILE);
 
     nwos_set_root_object(&root_object_ref);
 
