@@ -1,25 +1,66 @@
-/*             This file is part of the New World OS project
---                Copyright (C) 2006, 2007  QRW Software
+/*
+--             This file is part of the New World OS project
+--                 Copyright (C) 2006-2008  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
 --
--- NWOS is free software;  you can redistribute it and/or modify it under the
--- terms of the GNU General Public License  as published by the Free Software
--- Foundation; either version 2, or (at your option) any later version.  This
--- software is distributed with the hope that it will be useful,  but WITHOUT
--- ANY WARRANTY;  without  even the  implied warranty  of MERCHANTABILITY  or
--- FITNESS FOR A PARTICULAR PURPOSE.   See the GNU General Public License for
--- more  details.  You should have received a copy  of the GNU General Public
--- License along with this package;  see the file LICENSE.  If not, write to:
+--   This program is free software: you can redistribute it and/or modify
+--   it under the terms of the GNU General Public License as published by
+--   the Free Software Foundation, either version 3 of the License, or
+--   (at your option) any later version.
+--
+--   This program is distributed in the hope that it will be useful,
+--   but WITHOUT ANY WARRANTY; without even the implied warranty of
+--   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+--   GNU General Public License for more details.
+--
+--   You should have received a copy of the GNU General Public License
+--   along with this program, in the file LICENSE.  If not, see 
+--   <http://www.gnu.org/licenses/>.
+--
+--   You can also contact me via paper mail at:
+--
+--      QRW Software
+--      P.O. Box 27511
+--      Salt Lake City, UT 84127-0511, USA.
 --
---      Free Software Foundation
---      51 Franklin Street, Fifth Floor
---      Boston, MA 02110-1301
---      USA
---      http://www.fsf.org/licenses
 --
 -- $Log: list_files.c,v $
+-- Revision 1.22  2008/02/03 01:05:23  jsedwards
+-- Changed DEFAULT_TYPE_RO to READ_ONLY.
+--
+-- Revision 1.21  2008/01/22 13:40:03  jsedwards
+-- Updated year in copyright.
+--
+-- Revision 1.20  2008/01/22 13:30:33  jsedwards
+-- Added missing options to usage print and expanded to explain options.
+--
+-- Revision 1.19  2007/12/24 02:25:51  jsedwards
+-- Added --time and --revision options.
+--
+-- Revision 1.18  2007/08/25 22:48:27  jsedwards
+-- Fixed option name in usage print statement.
+--
+-- Revision 1.17  2007/08/25 21:55:09  jsedwards
+-- Added --list-old-files option and code to only print the old names of files
+-- that have been renamed if that option is set.
+--
+-- Revision 1.16  2007/08/23 13:43:58  jsedwards
+-- Removed unused code to read File Path class reference and emit error message
+-- when there isn't a private File and Path Association class (meaning no files
+-- exist in the system), instead of asserting.
+--
+-- Revision 1.15  2007/08/17 17:59:52  jsedwards
+-- Added code to deal with the case where a file object doesn't have a SHA256
+-- checksum, but the --sha256 option is enabled.
+--
+-- Revision 1.14  2007/08/17 16:48:54  jsedwards
+-- Added code to optionally print SHA256 checksums.
+--
+-- Revision 1.13  2007/07/01 19:44:12  jsedwards
+-- Upgrade to GPLv3.
+--
 -- Revision 1.12  2007/02/11 16:58:26  jsedwards
 -- Changed so DEFAULT_TYPE has to specify RO (Read-Only) or RW (Read-Write).
 --
@@ -80,6 +121,7 @@
 #include <string.h>
 
 #include "objectify.h"
+#include "time_stamp.h"
 
 
 static size_t get_path_object_size(void* file_path_obj)
@@ -118,6 +160,44 @@ void print_sha1(ObjRef* file_ref)
 }
 
 
+void print_sha256(ObjRef* file_ref)
+{
+    C_struct_File file_obj;
+    C_struct_SHA256sum sha256_object;
+    int j;
+
+    nwos_read_object_from_disk(file_ref, &file_obj, sizeof(file_obj));  /* read the file object */
+
+    if (is_void_reference(&file_obj.sha256sum))
+    {
+             /*          1         2         3         4         5         6     */
+             /* 1234567890123456789012345678901234567890123456789012345678901234 */
+
+	printf("*******  No SHA256 checksum is available for this file  ******* ");
+    }
+    else
+    {
+	nwos_read_object_from_disk(&file_obj.sha256sum, &sha256_object, sizeof(sha256_object));
+
+	for (j = 0; j < 32; j++) printf("%02x", sha256_object.sha256sum[j]);
+    }
+
+    printf("  ");
+}
+
+
+void print_time(TimeStamp ts)
+{
+    printf("  %u-%02u-%02u %02u:%02u:%02u",
+	   nwos_extract_year_from_time_stamp(ts),
+	   nwos_extract_month_from_time_stamp(ts),
+	   nwos_extract_day_of_month_from_time_stamp(ts),
+	   nwos_extract_hour_from_time_stamp(ts),
+	   nwos_extract_minute_from_time_stamp(ts),
+	   nwos_extract_second_from_time_stamp(ts));
+}
+
+
 int main(int argc, char* argv[])
 {
     ObjRef root_object_ref;
@@ -129,22 +209,28 @@ int main(int argc, char* argv[])
     C_struct_Path_And_File_Association assoc_obj;
     uint8 kludge[FILE_BLOCK_SIZE];
     C_struct_File_Path* ptr_path_obj = (C_struct_File_Path*)kludge;
-    ObjRef path_class_ref;
+    C_struct_File file_obj;
     ObjRef object_class;
     ObjRef assoc_class_ref;
+    ObjRef prev_ref;
+    ObjRef next_ref;
     ReferenceList* ref_list;
     int num_refs;
     int num_files = 0;
     int argn;
     int i;
     int j;
+    int revision;
     char name[256];
     bool do_md5 = false;
     bool do_sha1 = false;
+    bool do_sha256 = false;
+    bool do_list_old_names = false;
+    bool do_time = false;
+    bool do_revision = false;
     bool match;
 
 
-    StorageType type = DEFAULT_TYPE_RO;
     char* path = DEFAULT_FILE;
 
     argn = 1;
@@ -153,7 +239,6 @@ int main(int argc, char* argv[])
     {
 	if (strcmp(argv[argn], "--compressed") == 0 && argc > argn + 1)
 	{
-	    type = Compressed_File_RO;
 	    argn++;
 	    path = argv[argn];
 	    argn++;
@@ -168,9 +253,41 @@ int main(int argc, char* argv[])
 	    do_sha1 = true;
 	    argn++;
 	}
+	else if (strcmp(argv[argn], "--sha256") == 0)
+	{
+	    do_sha256 = true;
+	    argn++;
+	}
+	else if (strcmp(argv[argn], "--time") == 0)
+	{
+	    do_time = true;
+	    argn++;
+	}
+	else if (strcmp(argv[argn], "--list-old-names") == 0)
+	{
+	    do_list_old_names = true;
+	    argn++;
+	}
+	else if (strcmp(argv[argn], "--revision") == 0)
+	{
+	    do_revision = true;
+	    argn++;
+	}
 	else
 	{
-	    fprintf(stderr, "usage: %s [--compressed compressed-file] [--md5] [--sha1] files to extract\n", argv[0]);
+	    fprintf(stderr, "usage: %s [--compressed compressed-file] [--time] [--md5 | --sha1 | --sha256] [--list-old-names] [--revision] [FILES]...\n", argv[0]);
+	    fprintf(stderr, "\n");
+	    fprintf(stderr, "List information about the files stored or logged in Objectify.\n");
+	    fprintf(stderr, "If no files are specified, all files stored and logged are printed.\n");
+	    fprintf(stderr, "\n");
+	    fprintf(stderr, "  --list-old-names  print old names of files (that have been renamed)\n");
+	    fprintf(stderr, "  --md5             print md5 sum of each file\n");
+	    fprintf(stderr, "  --revision        print revision of each file\n");
+	    fprintf(stderr, "  --sha1            print sha1 sum of each file\n");
+	    fprintf(stderr, "  --sha256          print sha256 sum of each file\n");
+	    fprintf(stderr, "  --time            print modification time for each file\n");
+	    fprintf(stderr, "\n");
+	    fprintf(stderr, "Only one of --md5, --sha1, --sha256 can be specified at a time.\n\n");
 	    exit(1);
 	}
 
@@ -185,14 +302,16 @@ int main(int argc, char* argv[])
     memcpy(root_object_ref.id, big_key+20, 4);
     serial = ((uint32)big_key[24] << 24) | ((uint32)big_key[25] << 16) | ((uint32)big_key[26] << 8) | (uint32)big_key[27];
 
-    nwos_initialize_objectify(bf_key, linear, serial, type, path);
+    nwos_initialize_objectify(bf_key, linear, serial, READ_ONLY, path);
 
     nwos_set_root_object(&root_object_ref);
 
 
-    assert(nwos_find_private_class_definition("FILE PATH", &path_class_ref));
-
-    assert(nwos_find_private_class_definition("PATH AND FILE ASSOCIATION", &assoc_class_ref));
+    if (!nwos_find_private_class_definition("PATH AND FILE ASSOCIATION", &assoc_class_ref))
+    {
+	printf("No files are stored in the system!\n");
+	exit(1);
+    }
 
     nwos_read_class_definition(&assoc_class_ref, &class_def_obj);
 
@@ -210,30 +329,33 @@ int main(int argc, char* argv[])
 	  {
 	    nwos_read_object_from_disk(&ref_list->references[i], &assoc_obj, sizeof(assoc_obj));
 
-	    nwos_read_variable_sized_object_from_disk(&assoc_obj.path, kludge, sizeof(kludge), &get_path_object_size);
+	    match = false;
 
-	    /* remember ptr_path_obj points to the kludge buffer */
-
-	    for (j = 0; j < ptr_path_obj->count; j++) name[j] = ptr_path_obj->storage[j];
-
-	    name[j] = '\0';
-
-	    if (argn < argc)    /* file names were passed to the program on the command line */
+	    if (do_list_old_names || is_void_reference(&assoc_obj.header.object.next_version))
 	    {
-		match = false;
+		nwos_read_variable_sized_object_from_disk(&assoc_obj.path, kludge, sizeof(kludge), &get_path_object_size);
 
-		for (j = argn; j < argc; j++)
+		/* remember ptr_path_obj points to the kludge buffer */
+
+		for (j = 0; j < ptr_path_obj->count; j++) name[j] = ptr_path_obj->storage[j];
+
+		name[j] = '\0';
+
+		if (argn < argc)    /* file names were passed to the program on the command line */
 		{
-		    if (fnmatch(argv[j], name, 0) == 0)   /* found a match */
+		    for (j = argn; j < argc; j++)
 		    {
-			match = true;
-			break;
+			if (fnmatch(argv[j], name, 0) == 0)   /* found a match */
+			{
+			    match = true;
+			    break;
+			}
 		    }
 		}
-	    }
-	    else             /* no filenames specified on command line */
-	    {
-		match = true;   /* list all files */
+		else             /* no filenames specified on command line */
+		{
+		    match = true;   /* list all files */
+		}
 	    }
 
 	    if (match)
@@ -248,7 +370,34 @@ int main(int argc, char* argv[])
 		    print_sha1(&assoc_obj.file);
 		}
 
-		printf("%s\n", name);
+		if (do_sha256)
+		{
+		    print_sha256(&assoc_obj.file);
+		}
+
+		printf("%s", name);
+
+		if (do_revision)
+		{
+		    nwos_read_object_from_disk(&assoc_obj.file, &file_obj, sizeof(file_obj));
+		    revision = 1;
+		    while (!is_void_reference(&file_obj.header.object.prev_version))
+		    {
+			copy_reference(&next_ref, &file_obj.header.common.id);
+			copy_reference(&prev_ref, &file_obj.header.object.prev_version);
+			nwos_read_object_from_disk(&prev_ref, &file_obj, sizeof(file_obj));
+			assert(is_same_object(&file_obj.header.object.next_version, &next_ref));
+			revision++;
+		    }
+		    printf(";%d", revision);
+		}
+
+		if (do_time)
+		{
+		    print_time(assoc_obj.modification_time);
+		}
+
+		printf("\n");
 
 		num_files++;
 	    }
