@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2004-2007  QRW Software
+--                 Copyright (C) 2004-2008  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,15 @@
 --
 --
 -- $Log: log.c,v $
+-- Revision 1.12  2008/02/05 04:23:44  jsedwards
+-- Added include of objectify_private.h.  Removed forward references for
+-- strlcat and strlcpy because they are declared in objectify.h.  Changed to
+-- get the log file path from the new nwos_get_log_file_path function.
+-- Added 'const' specifier to strlcat and strlcpy.
+--
+-- Revision 1.11  2008/01/13 20:09:06  jsedwards
+-- Added nwos_log_md5sum, nwos_log_sha1sum, and nwos_log_sha256sum functions.
+--
 -- Revision 1.10  2007/10/27 14:55:21  jsedwards
 -- Changed to use #ifndef STRLCAT and #ifndef STRLCPY instead of #ifdef linux.
 --
@@ -73,16 +82,9 @@
 #include <time.h>
 #include <unistd.h>
 
-#include "config.h"   /* for the log file path */
+#include "objectify.h" /* include this for config.h the log file path and because these functions prototypes are there */
+#include "objectify_private.h"  /* include this to get the nwos_get_log_file_path function */
 
-/* forward references for functions that aren't standard */
-#ifndef HAVE_STRLCPY
-size_t strlcpy(char* dst, char* src, size_t len);
-#endif
-
-#ifndef HAVE_STRLCAT
-size_t strlcat(char* dst, char* src, size_t len);
-#endif
 
 
 /******************************************/
@@ -141,7 +143,7 @@ void nwos_log(char* str)
     char time_str[32];
     static char* log_file_path;
     size_t path_len;
-    char* home_dir;
+    const char* path;
 
     gettimeofday(&tv, NULL);
     strncpy(time_str, ctime((time_t*)&tv.tv_sec), 32);
@@ -149,29 +151,13 @@ void nwos_log(char* str)
 
     if (log_file_path == NULL)
     {
-	home_dir = getenv("HOME");
+	path = nwos_get_log_file_path();
+	path_len = strlen(path) + 1 + 8 + 4 + 1;
 
-	if (home_dir == NULL)   /* no home directory?? */
-	{
-	    path_len = strlen(LOG_FILE_NAME) + 1 + 8 + 4 + 1;
+	log_file_path = malloc(path_len);
+	assert(log_file_path != NULL);
 
-	    log_file_path = malloc(path_len);
-	    assert(log_file_path != NULL);
-
-	    *log_file_path = '\0';
-	}
-	else
-	{
-	    path_len = strlen(home_dir) + 1 + strlen(LOG_FILE_NAME) + 1 + 8 + 4 + 1;
-
-	    log_file_path = malloc(path_len);
-	    assert(log_file_path != NULL);
-
-	    strlcpy(log_file_path, home_dir, path_len);
-	    strlcat(log_file_path, "/", path_len);
-	}
-
-	strlcat(log_file_path, LOG_FILE_NAME, path_len);
+	strlcpy(log_file_path, path, path_len);
 	strlcat(log_file_path, "-", path_len);
 	append_date_from_time_string(log_file_path, time_str, path_len);
 	strlcat(log_file_path, ".txt", path_len);
@@ -228,10 +214,88 @@ void nwos_log_arguments(int argc, char* argv[])
 }
 
 
+static char hexdigit[16] = { '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'a', 'b', 'c', 'd', 'e', 'f' };
+
+void nwos_log_md5sum(char* file_name, uint8 md5_digest[MD5_DIGEST_SIZE])
+{
+    char msg[12 + FILENAME_MAX + MD5_DIGEST_SIZE * 2] = "MD5 (";
+    int prefix_len;
+    int i;
+
+    strlcat(msg, file_name, sizeof(msg));
+    strlcat(msg, ") = ", sizeof(msg));
+
+    prefix_len = strlen(msg);
+
+    assert(prefix_len + MD5_DIGEST_SIZE < sizeof(msg));
+
+    for (i = 0; i < MD5_DIGEST_SIZE; i++)
+    {
+	msg[prefix_len + i * 2] = hexdigit[md5_digest[i] >> 4];
+	msg[prefix_len + i * 2 + 1] = hexdigit[md5_digest[i] & 0xf];
+    }
+
+    msg[prefix_len + i * 2] = '\0';
+
+    nwos_log(msg);
+}
+
+
+void nwos_log_sha1sum(char* file_name, uint8 sha1_digest[SHA1_DIGEST_SIZE])
+{
+    char msg[12 + FILENAME_MAX + SHA1_DIGEST_SIZE * 2] = "SHA1 (";
+    int prefix_len;
+    int i;
+
+    strlcat(msg, file_name, sizeof(msg));
+    strlcat(msg, ") = ", sizeof(msg));
+
+    prefix_len = strlen(msg);
+
+    assert(prefix_len + SHA1_DIGEST_SIZE < sizeof(msg));
+
+    for (i = 0; i < SHA1_DIGEST_SIZE; i++)
+    {
+	msg[prefix_len + i * 2] = hexdigit[sha1_digest[i] >> 4];
+	msg[prefix_len + i * 2 + 1] = hexdigit[sha1_digest[i] & 0xf];
+    }
+
+    msg[prefix_len + i * 2] = '\0';
+
+    nwos_log(msg);
+}
+
+
+void nwos_log_sha256sum(char* file_name, uint8 sha256_digest[SHA256_DIGEST_SIZE])
+{
+    char msg[16 + FILENAME_MAX + SHA256_DIGEST_SIZE * 2] = "SHA256 (";
+    int prefix_len;
+    int i;
+
+    strlcat(msg, file_name, sizeof(msg));
+    strlcat(msg, ") = ", sizeof(msg));
+
+    prefix_len = strlen(msg);
+
+    assert(prefix_len + SHA256_DIGEST_SIZE < sizeof(msg));
+
+    for (i = 0; i < SHA256_DIGEST_SIZE; i++)
+    {
+	msg[prefix_len + i * 2] = hexdigit[sha256_digest[i] >> 4];
+	msg[prefix_len + i * 2 + 1] = hexdigit[sha256_digest[i] & 0xf];
+    }
+
+    msg[prefix_len + i * 2] = '\0';
+
+    nwos_log(msg);
+}
+
+
+
 /* since neither Linux or GNU seem to have these functions */
 
 #ifndef HAVE_STRLCPY
-size_t strlcpy(char* dst, char* src, size_t len)
+size_t strlcpy(char* dst, const char* src, size_t len)
 {
     int i;
 
@@ -258,7 +322,7 @@ size_t strlcpy(char* dst, char* src, size_t len)
 
 
 #ifndef HAVE_STRLCAT
-size_t strlcat(char* dst, char* src, size_t len)
+size_t strlcat(char* dst, const char* src, size_t len)
 {
     int i, j;
 
