@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2004-2007  QRW Software
+--                 Copyright (C) 2004-2008  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,21 @@
 --
 --
 -- $Log: objectify.c,v $
+-- Revision 1.142  2008/02/03 02:14:42  jsedwards
+-- Change parameter to initialize_objectify to AccessType instead of StorgeType
+-- and add 'const' to path parameter.
+--
+-- Revision 1.141  2008/02/03 02:13:00  jsedwards
+-- Fixed to compile in PUBLIC_MODE without warnings.
+--
+-- Revision 1.140  2008/01/18 03:22:32  jsedwards
+-- Rearranged code in nwos_create_root to not see if the block has been
+-- written already, instead test the bit map.
+--
+-- Revision 1.139  2007/12/25 14:26:18  jsedwards
+-- Added #ifndef PUBLIC_MODE around code to upgrade file object, it is not
+-- needed in PUBLIC_MODE and this way there is no need to include file.o.
+--
 -- Revision 1.138  2007/11/24 16:59:42  jsedwards
 -- Fixed to compile correctly when compiled with PUBLIC_MODE defined.
 --
@@ -787,7 +802,9 @@ ObjRef nwos_public_class_definition_class_ref;
 ObjRef nwos_private_class_definition_class_ref;
 ObjRef nwos_reference_list_class_ref;
 
+#ifndef PUBLIC_MODE
 static Security_Level security_level = Security_None;
+#endif
 
 #define SECURITY_VERY_LOW_N  7     /* sort of arbitrary, but it's always fun to use prime numbers */
 #define SECURITY_LOW_N      43     /* in this case each digit is represented */
@@ -802,7 +819,9 @@ static uint32 serial_after_first;
 
 uint8  nwos_random_sequence[NUM_STORED_SEQ][FILE_BLOCK_SIZE];     /* this will only work for blocks <= 256 bytes */
 
+#ifndef PUBLIC_MODE
 static BF_KEY blowfish_key;
+#endif
 
 
 
@@ -967,7 +986,7 @@ static void generate_sequence_table(uint32* linear, uint32* serial, uint8 table[
 /* Initialization and Termination */
 /**********************************/
 
-void nwos_initialize_objectify(uint8 bf_key[16], uint32 linear_seed, uint32 serial_seed, StorageType type, char* path)
+void nwos_initialize_objectify(uint8 bf_key[16], uint32 linear_seed, uint32 serial_seed, AccessType type, const char* path)
 {
 #ifndef PUBLIC_MODE
     int i;
@@ -1040,15 +1059,18 @@ bool nwos_create_root(ObjRef* ref)
     ObjRef root_class_ref;
     bool result = false;
 
-#ifndef PUBLIC_MODE
-    nwos_set_bit_in_map(nwos_hash_ref(ref));
-#endif
-
     /* first find out if we already have this root */
 
-
-    if (!nwos_object_exists(ref))   /* it already exists */
+#ifdef PUBLIC_MODE
+    if (!nwos_object_exists(ref))   /* not already used */
     {
+#else
+    uint32 hash = nwos_hash_ref(ref);
+
+    if (!nwos_test_bit_in_map(hash))   /* not already used */
+    {
+	nwos_set_bit_in_map(hash);
+#endif
 	/* currently I can't think of any reason to have a private root class, since there is no list of root objects */
 	assert(nwos_find_public_class_definition("ROOT", &root_class_ref));
 
@@ -1383,11 +1405,13 @@ void compare_bufs(uint8 buf1[FILE_BLOCK_SIZE], uint8 buf2[FILE_BLOCK_SIZE], char
 
 void nwos_read_object_from_disk_and_decrypt(ObjRef* ref, void* object, size_t size, uint8 ivec[IVEC_SIZE], uint8 seq_table[FILE_BLOCK_SIZE])
 {
-    uint8 buffer1[FILE_BLOCK_SIZE];
     uint8 buffer2[FILE_BLOCK_SIZE];
+#ifndef PUBLIC_MODE
+    uint8 buffer1[FILE_BLOCK_SIZE];
     uint8* ptrobj = (uint8*)object;
     int i;
     int j;
+#endif
 
     assert(!is_void_reference(ref));
 
@@ -1613,6 +1637,7 @@ void nwos_read_object_from_disk(ObjRef* ref, void* object, size_t size)
     check_object_header(ref, &header->object, header->common.header_chksum);
 
 #ifndef USE_PREDEFINED_STRUCTS
+#ifndef PUBLIC_MODE
     /* check to see if this is a file object (which has an older revision) */
     if (is_same_object(&header->common.class_definition, get_file_001_reference()))
     {
@@ -1620,6 +1645,7 @@ void nwos_read_object_from_disk(ObjRef* ref, void* object, size_t size)
 	nwos_update_file_001_object_to_current(object, size);
     }
     else
+#endif
 #endif
     {
 	check_object_data(ref, (uint8*)object, size, header->common.data_chksum);
@@ -1750,11 +1776,13 @@ void nwos_read_object_headers_from_disk(ObjRef* ref, EveryObject* header)
 
 void nwos_write_object_to_disk_and_encrypt(ObjRef* ref, void* object, size_t size, uint8 ivec[IVEC_SIZE], uint8 seq_table[FILE_BLOCK_SIZE])
 {
-    uint8 buffer1[FILE_BLOCK_SIZE];
     uint8 buffer2[FILE_BLOCK_SIZE];
+#ifndef PUBLIC_MODE
+    uint8 buffer1[FILE_BLOCK_SIZE];
     uint8* ptrobj = (uint8*)object;
     int i;
     int j;
+#endif
 
     assert(!is_void_reference(ref));
     assert(size <= FILE_BLOCK_SIZE);
