@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2004-2007  QRW Software
+--                 Copyright (C) 2004-2008  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,19 @@
 --
 --
 -- $Log: objectify.h,v $
+-- Revision 1.128  2008/02/05 04:17:19  jsedwards
+-- Added 'const' to the source string parameter in the strlcat and strlcpy
+-- function declarations.
+--
+-- Revision 1.127  2008/02/03 01:08:56  jsedwards
+-- Moved StorageType enumeration from config.h and renamed to AccessType.
+-- Added definition for DEFAULT_FILE to a NULL which tells disk_io.c to use
+-- the default path (as opposed to a compressed file).
+--
+-- Revision 1.126  2008/01/13 19:41:36  jsedwards
+-- Added defines for MD5_DIGEST_SIZE, SHA1_DIGEST_SIZE, SHA256_DIGEST_SIZE, and
+-- declarations for nwos_log_md5sum, nwos_log_sha1sum, and nwos_log_sha256sum.
+--
 -- Revision 1.125  2007/10/27 14:51:39  jsedwards
 -- Changed to use #ifndef STRLCAT and #ifndef STRLCPY instead of #ifdef linux.
 --
@@ -649,6 +662,12 @@
 
 #define MAGIC_NUMBER "NWOS"
 
+#define DEFAULT_FILE NULL      /* this used to define a path, now a null tells disk_io to use the default */
+
+typedef enum {
+  READ_ONLY  = 0x52454144,
+  READ_WRITE = 0x52445752,
+} AccessType;
 
 
 typedef union { uint8 id[4]; uint32 word; } ObjRef;
@@ -824,11 +843,11 @@ typedef enum { Security_None=0, Security_Minimal, Security_Very_Low, Security_Lo
 
 /* These functions aren't standard */
 #ifndef HAVE_STRLCPY
-extern size_t strlcpy(char* dst, char* src, size_t len);
+extern size_t strlcpy(char* dst, const char* src, size_t len);
 #endif
 
 #ifndef HAVE_STRLCAT
-extern size_t strlcat(char* dst, char* src, size_t len);
+extern size_t strlcat(char* dst, const char* src, size_t len);
 #endif
 
 extern void nwos_ref_to_name(ObjRef* ref, char name[]);
@@ -838,9 +857,18 @@ extern void nwos_ref_to_name(ObjRef* ref, char name[]);
 extern uint32 nwos_decode_variable_sized_count(uint8 count[4]);
 extern void   nwos_encode_variable_sized_count(uint32 count, uint8 result[4]);
 
+
+#define MD5_DIGEST_SIZE    16
+#define SHA1_DIGEST_SIZE   20
+#define SHA256_DIGEST_SIZE 32
+
 extern void nwos_log(char* str);
 extern void nwos_log_arguments(int argc, char* argv[]);
-extern void nwos_initialize_objectify(uint8 bf_key[16], uint32 linear, uint32 serial, StorageType type, char* path);
+extern void nwos_log_md5sum(char* file_name, uint8 md5_digest[MD5_DIGEST_SIZE]);
+extern void nwos_log_sha1sum(char* file_name, uint8 sha1_digest[SHA1_DIGEST_SIZE]);
+extern void nwos_log_sha256sum(char* file_name, uint8 sha256_digest[SHA256_DIGEST_SIZE]);
+
+extern void nwos_initialize_objectify(uint8 bf_key[16], uint32 linear, uint32 serial, AccessType type, const char* path);
 extern void nwos_terminate_objectify();
 extern void nwos_set_root_object(ObjRef* ref);
 extern void nwos_flush_bit_maps();
