@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2004-2007  QRW Software
+--                 Copyright (C) 2004-2008  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,21 @@
 --
 --
 -- $Log: objectify_private.h,v $
+-- Revision 1.63  2008/02/05 04:21:06  jsedwards
+-- Added external declaration for nwos_get_log_file_path.
+--
+-- Revision 1.62  2008/02/04 03:04:32  jsedwards
+-- Added external declaration for nwos_get_backup_directory_path and added
+-- 'const' to nwos_initialize_backup path parameter.
+--
+-- Revision 1.61  2008/02/02 18:31:51  jsedwards
+-- Added external declaration for nwos_get_private_objects_path.  Added
+-- 'const' to nwos_public_path and nwos_private_path.  Changed StorageType to
+-- AccessType in nwos_initialize_disk_io parameters.
+--
+-- Revision 1.60  2008/01/22 14:52:59  jsedwards
+-- Added external declaration for nwos_get_public_objects_path.
+--
 -- Revision 1.59  2007/11/09 15:44:20  jsedwards
 -- Added externs for backup.c module.
 --
@@ -409,6 +424,10 @@ extern ObjRef nwos_private_class_definition_class_ref;
 extern ObjRef nwos_reference_list_class_ref;
 extern ObjRef nwos_next_public_ref;
 
+extern const char* nwos_get_public_objects_path();
+extern const char* nwos_get_private_objects_path();
+extern const char* nwos_get_log_file_path();
+extern const char* nwos_get_backup_directory_path();
 
 extern void nwos_create_class_definition(char* name_of_class);
 extern void nwos_clone_class_definition(ObjRef* class_to_clone_ref, ObjRef* clone_ref);
@@ -450,11 +469,11 @@ extern uint32 nwos_next_sequence(uint32* linear_seed, uint32* serial_seed);
 extern void nwos_read_object_from_disk_and_decrypt(ObjRef* ref, void* object, size_t size, uint8 ivec[IVEC_SIZE], uint8 seq_table[FILE_BLOCK_SIZE]);
 extern void nwos_write_object_to_disk_and_encrypt(ObjRef* ref, void* object, size_t size, uint8 ivec[IVEC_SIZE], uint8 seq_table[FILE_BLOCK_SIZE]);
 
-extern char* nwos_public_path;
-extern char* nwos_private_path;
-extern void  nwos_initialize_disk_io(StorageType type, char* path);
+extern const char* nwos_public_path;
+extern const char* nwos_private_path;
+extern void  nwos_initialize_disk_io(AccessType type, const char* path);
 extern void  nwos_terminate_disk_io();
-extern void  nwos_initialize_backup(char* path, Disk_Header* disk_header);
+extern void  nwos_initialize_backup(const char* path, Disk_Header* disk_header);
 extern void  nwos_terminate_backup(bool modified, Disk_Header* disk_header);
 extern void  nwos_backup_write_block(uint8 block[FILE_BLOCK_SIZE]);
 extern void  nwos_set_allocation_parameters(uint32 density, int32 skip_backward, int32 skip_forward);
